@@ -7,7 +7,7 @@ use File::Spec;
 use File::HomeDir;
 
 # ABSTRACT: A framework for RESTful processing systems.
-our $VERSION = '1.07'; # VERSION
+our $VERSION = '1.08'; # VERSION
 
 
 sub _testing
@@ -44,6 +44,20 @@ sub _slurp_pid ($)
   $pid;
 }
 
+sub _dist_dir
+{
+  require Path::Class::File;
+  require Path::Class::Dir;
+  $_ = __FILE__; s{(Clustericious).pm}{.$1.devshare}; -e $_
+    ? Path::Class::File->new(__FILE__)->parent->parent->subdir('share')
+    : do {
+      require File::ShareDir;
+      Path::Class::Dir->new(
+        File::ShareDir::dist_dir('Clustericious'),
+      );
+    }
+}
+
 # Note sub _config_uncache also gets placed
 # in this package, but it is defined in
 # Clustericious::Config.
@@ -62,7 +76,7 @@ Clustericious - A framework for RESTful processing systems.
 
 =head1 VERSION
 
-version 1.07
+version 1.08
 
 =head1 SYNOPSIS
 
@@ -70,10 +84,6 @@ Generate a new Clustericious application:
 
  % clustericious generate app MyApp
 
-Generate a new Clustericious application database schema:
-
- % clustericious generate mbd_app MyApp --schema schema.sql
-
 Basic application layout:
 
  package MyApp;
