@@ -1,4 +1,3 @@
-
 package Clustericious::App;
 
 use strict;
@@ -19,13 +18,12 @@ use File::HomeDir ();
 use Carp qw( cluck );
 use Clustericious::Controller;
 use Clustericious::Renderer;
-use Clustericious::RouteBuilder;
 use Clustericious::RouteBuilder::Common;
 use Clustericious::Config;
 use Clustericious::Commands;
 
 # ABSTRACT: Clustericious app base class
-our $VERSION = '1.07'; # VERSION
+our $VERSION = '1.08'; # VERSION
 
 
 sub _have_rose {
@@ -58,6 +56,13 @@ sub Math::BigInt::TO_JSON {
 }
 
 
+my @route_builders;
+
+sub _add_route_builder
+{
+  push @route_builders, $_[1];
+}
+
 sub startup {
     my $self = shift;
 
@@ -78,25 +83,7 @@ sub startup {
     }
 
     $self->plugins->namespaces(['Mojolicious::Plugin','Clustericious::Plugin']);
-    my $config = eval { Clustericious::Config->new(ref $self) };
-    if(my $error = $@)
-    {
-        $self->log->error("error loading config $error");
-        $config = Clustericious::Config->new({ clustericious_config_error => $error });
-    }
-    else
-    {
-        if($config->{url})
-        {
-            # populate start mode and hypntoad with defaults if
-            # they are not specified in the configuration
-            $config->_default_start_mode;
-            $config->hypnotoad 
-              if ref $config->{start_mode} eq 'ARRAY'
-              && @{ $config->{start_mode} } == 1
-              && $config->{start_mode}->[0] eq 'hypnotoad';
-        }
-    }
+    my $config = $self->config;
     my $auth_plugin;
     if(my $auth_config = $config->plug_auth(default => '')) {
         $self->log->info("Loading auth plugin plug_auth");
@@ -114,7 +101,7 @@ sub startup {
     my $r = $self->routes;
     # "Common" ones are not overrideable.
     Clustericious::RouteBuilder::Common->_add_routes($self);
-    Clustericious::RouteBuilder->_add_routes($self, $auth_plugin);
+    $_->($self, $auth_plugin) for @route_builders;
 
     $self->plugin('AutodataHandler');
     $self->plugin('DefaultHelpers');
@@ -130,7 +117,6 @@ sub startup {
         $self->log->warn("Configuration file should contain 'url'.");
     };
 
-    $self->helper( _clustericious_config => sub { $config } );
     $self->helper( url_with => sub {
         my $c = shift;
         my $q = $c->req->url->clone->query;
@@ -262,13 +248,41 @@ sub dump_api_table
 
 
 sub config {
-    my $app = shift;
-    if (my $what = shift) {
-        # Mojo config interface
-        $app->_clustericious_config(@_)->{$what};
-    } else {
-        $app->_clustericious_config(@_);
+  my($self, $what) = @_;
+
+  unless($self->{_config})
+  {
+    my $config = $self->{_config} = eval { Clustericious::Config->new(ref $self) };
+    if(my $error = $@)
+    {
+      $self->log->error("error loading config $error");
+      $config = $self->{_config} = Clustericious::Config->new({ clustericious_config_error => $error });
     }
+
+    if($config->{url})
+    {
+      if(grep { $_ eq 'hypnotoad' } $config->start_mode(default => [ 'hypnotoad' ]) )
+      {
+        my $hypnotoad = $config->hypnotoad(
+          default => sub {
+            my $url = Mojo::URL->new($config->{url});
+            {
+              pid_file => File::Spec->catfile( File::HomeDir->my_dist_data("Clustericious", { create => 1 } ), 'hypnotoad-' . $url->port . '-' . $url->host . '.pid' ),
+              listen => [
+                $url->to_string,
+              ],
+            };
+          }
+        );
+      }
+    }
+  }
+
+  my $config = $self->{_config};
+
+  # Mojo uses $app->config('what');
+  # Clustericious usually uses $app->config->what;
+  $what ? $config->{$what} : $config;
 }
 
 
@@ -286,11 +300,6 @@ sub sanity_check
     $sane;
 }
 
-sub _start_mode
-{
-  shift->config->_default_start_mode;
-}
-
 1;
 
 __END__
@@ -305,7 +314,7 @@ Clustericious::App - Clustericious app base class
 
 =head1 VERSION
 
-version 1.07
+version 1.08
 
 =head1 SYNOPSIS
 
