@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 # ABSTRACT: Command line type processing for clients.
-our $VERSION = '1.07'; # VERSION
+our $VERSION = '1.08'; # VERSION
 
 
 use File::Basename qw/basename/;
@@ -96,7 +96,6 @@ sub run {
     my $class = shift;
     my $client = shift;
     my @args = @_ ? @_ : @ARGV;
-    our $TESTING;
 
     return $class->_usage($client) if !$args[0] || $args[0] =~ /help/;
 
@@ -164,7 +163,7 @@ sub run {
             }
             INFO $msg;
         } else {
-           print _prettyDump($obj) unless $TESTING;
+           print _prettyDump($obj);
         }
         return;
     }
@@ -223,7 +222,7 @@ sub run {
             }
             INFO $msg;
         } else {
-           print _prettyDump($obj) unless $TESTING;
+           print _prettyDump($obj);
         }
     }
     return;
@@ -250,7 +249,7 @@ Clustericious::Client::Command - Command line type processing for clients.
 
 =head1 VERSION
 
-version 1.07
+version 1.08
 
 =head1 SYNOPSIS
 
