@@ -5,7 +5,7 @@ use warnings;
 use Mojo::Base 'Mojolicious::Command';
 
 # ABSTRACT: Command base class
-our $VERSION = '1.07'; # VERSION
+our $VERSION = '1.08'; # VERSION
 
 
 1;
@@ -22,11 +22,7 @@ Clustericious::Command - Command base class
 
 =head1 VERSION
 
-version 1.07
-
-=head1 SYNOPSIS
-
- use Mojo::Base 'Mojolicious::Command';
+version 1.08
 
 =head1 DESCRIPTION
 
@@ -42,19 +38,23 @@ This is a (not exhaustive) list of common Clustericious commands:
 
 =item *
 
-L<hypnotoad|Clustericious::Command::hypnotoad>
+L<apache|Clustericious::Command::apache>
 
 =item *
 
-L<start|Clustericious::Command::start>
+L<configdebug|Clustericious::Command::configdebug>
 
 =item *
 
-L<stop|Clustericious::Command::stop>
+L<configpath|Clustericious::Command::configpath>
 
 =item *
 
-L<status|Clustericious::Command::status>
+L<configtest|Clustericious::Command::configtest>
+
+=item *
+
+L<configure|Clustericious::Command::configure>
 
 =item *
 
@@ -66,14 +66,30 @@ L<generate client|Clustericious::Command::generate::client>
 
 =item *
 
-L<generate mbd_app|Clustericious::Command::generate::mbd_app>
+L<hypnotoad|Clustericious::Command::hypnotoad>
+
+=item *
+
+L<lighttpd|Clustericious::Command::lighttpd>
+
+=item *
+
+L<plackup|Clustericious::Command::plackup>
+
+=item *
+
+L<start|Clustericious::Command::start>
+
+=item *
+
+L<status|Clustericious::Command::status>
+
+=item *
+
+L<stop|Clustericious::Command::stop>
 
 =back
 
-=head1 SUPER CLASS
-
-L<Mojolicious::Command>
-
 =head1 SEE ALSO
 
 L<Clustericious>
