@@ -8,7 +8,7 @@ use Clustericious::Config;
 use YAML::XS qw( Dump );
 
 # ABSTRACT: Debug a clustericious configuration file
-our $VERSION = '1.07'; # VERSION
+our $VERSION = '1.08'; # VERSION
 
 
 has description => <<EOT;
@@ -22,46 +22,63 @@ EOT
 
 sub run
 {
-  my $self = shift;
-  my $app_name = $_[0] || ref($self->app);
+  my($self, $name) = @_;
+  my $app_name = $name // ref($self->app);
 
   $ENV{MOJO_TEMPLATE_DEBUG} = 1;
 
-  my $config = Clustericious::Config->new($app_name, sub {
-    my $type = shift;
-    
-    if($type eq 'pre_rendered')
-    {
-      my($src) = @_;
-      my $data;
-      if(ref $src)
-      {
-        say "[SCALAR :: template]";
-        $data = $$src;
-      }
-      else
-      {
-        say "[$src :: template]";
-        open my $fh, '<', $src;
-        local $/;
-        $data = <$fh>;
-        close $fh;
-      }
-      chomp $data;
-      say $data;
-    }
-    elsif($type eq 'rendered')
-    {
-      my($file, $content) = @_;
-      say "[$file :: interpreted]";
-      chomp $content;
-      say $content;
-    }
-  });
+  my $exit = 0;
 
-  say "[merged]";
-  print Dump({ %$config });
+  eval { 
+    my $config = Clustericious::Config->new($app_name, sub {
+      my $type = shift;
 
+      if($type eq 'pre_rendered')
+      {
+        my($src) = @_;
+        my $data;
+        if(ref $src)
+        {
+          say "[SCALAR :: template]";
+          $data = $$src;
+        }
+        else
+        {
+          say "[$src :: template]";
+          open my $fh, '<', $src;
+          local $/;
+          $data = <$fh>;
+          close $fh;
+        }
+        chomp $data;
+        say $data;
+      }
+      elsif($type eq 'rendered')
+      {
+        my($file, $content) = @_;
+        say "[$file :: interpreted]";
+        chomp $content;
+        say $content;
+      }
+      elsif($type eq 'not_found')
+      {
+        say STDERR "ERROR: unable to find $_[0]";
+        $exit = 2;
+      }
+    });
+
+    say "[merged]";
+    print Dump({ %$config });
+
+  };
+  
+  if(my $error = $@)
+  {
+    say STDERR "ERROR: in syntax: $error";
+    $exit = 2;
+  }
+
+  exit $exit;
 };
 
 1;
@@ -78,7 +95,7 @@ Clustericious::Command::configdebug - Debug a clustericious configuration file
 
 =head1 VERSION
 
-version 1.07
+version 1.08
 
 =head1 SYNOPSIS
 
