@@ -7,7 +7,7 @@ use Mojo::Base 'Clustericious::Command';
 use Clustericious;
 
 # ABSTRACT: Print the configuration path
-our $VERSION = '1.07'; # VERSION
+our $VERSION = '1.08'; # VERSION
 
 
 has description => <<EOT;
@@ -20,9 +20,7 @@ EOT
 
 sub run
 {
-  my $self = shift;
-  my @args = @_ ? @_ : @ARGV;
-
+  my($self, @args) = @_;
   say for Clustericious->_config_path  
 }
 
@@ -40,7 +38,7 @@ Clustericious::Command::configpath - Print the configuration path
 
 =head1 VERSION
 
-version 1.07
+version 1.08
 
 =head1 SYNOPSIS
 
