@@ -6,7 +6,7 @@ use 5.010;
 use Mojo::Base 'Clustericious::Command';
 
 # ABSTRACT: Test a Clustericious application's configuration
-our $VERSION = '1.07'; # VERSION
+our $VERSION = '1.08'; # VERSION
 
 
 has description => <<EOT;
@@ -20,13 +20,8 @@ EOT
 
 sub run
 {
-  my $self = shift;
-  my @args = @_ ? @_ : @ARGV;
-  
-  my $app = $self->app;
-  
-  exit 2 unless $app->sanity_check;
-  
+  my($self, @args) = @_;
+  exit 2 unless $self->app->sanity_check;
   say 'config okay';
 }
 
@@ -44,7 +39,7 @@ Clustericious::Command::configtest - Test a Clustericious application's configur
 
 =head1 VERSION
 
-version 1.07
+version 1.08
 
 =head1 SYNOPSIS
 
@@ -78,10 +73,6 @@ do a sanity check of the configuration:
 This command does a basic sanity check on the configuration for your Clustericious
 application, and calls the application's C<sanity_check>
 
-=head1 SUPER CLASS
-
-L<Clustericious::Command>
-
 =head1 SEE ALSO
 
 L<Clustericious>
