@@ -6,8 +6,7 @@ use base qw( Clustericious::Command );
 use Mojolicious::Command::daemon;
 
 # ABSTRACT: Clustericious command to stat nginx
-our $VERSION = '1.28_01'; # TRIAL VERSION
-$VERSION = eval $VERSION;
+our $VERSION = '1.08'; # VERSION
 
 
 sub description { Mojolicious::Command::daemon->new->description };
@@ -17,14 +16,11 @@ sub run
 {
   my($self, @args) = @_;
   
-  if(!grep /^-l/, @args)
+  if(my $url = $self->app->config->{url})
   {
-    if(my $url = $self->app->config->{url})
-    {
-      unshift @args, -l => $url;
-    }
+    unshift @args, -l => $url;
   }
-
+  
   Mojolicious::Command::daemon::run($self, @args);
 }
 
@@ -42,7 +38,7 @@ Clustericious::Command::daemon - Clustericious command to stat nginx
 
 =head1 VERSION
 
-version 1.28_01
+version 1.08
 
 =head1 DESCRIPTION
 
@@ -67,8 +63,6 @@ Contributors:
 
 Curt Tilmes
 
-Yanick Champoux
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by NASA GSFC.
