@@ -5,7 +5,7 @@ use warnings;
 use Mojo::Base 'Mojolicious::Command::generate';
 
 # ABSTRACT: Clustericious code generation commands.
-our $VERSION = '1.07'; # VERSION
+our $VERSION = '1.08'; # VERSION
 
 
 has namespaces =>
@@ -27,11 +27,12 @@ Clustericious::Command::generate - Clustericious code generation commands.
 
 =head1 VERSION
 
-version 1.07
+version 1.08
 
 =head1 SYNOPSIS
 
- % clustericious generate mbd_app Myapp --schema schema.sql
+ % clustericious generate app MyApp
+ % clustericious generate client MyApp
 
 =head1 DESCRIPTION
 
@@ -39,10 +40,6 @@ This is the base class for all Clustericious code generation commands.
 It inherits from L<Mojolicious::Command::generate> instead of
 L<Clustericious::Command>.
 
-=head1 SUPER CLASS
-
-L<Mojolicious::Command::generate>
-
 =head1 SEE ALSO
 
 L<Clustericious>
