@@ -9,8 +9,7 @@ use File::Which qw( which );
 use Capture::Tiny qw( capture );
 
 # ABSTRACT: Clustericious command to stat nginx
-our $VERSION = '1.28_01'; # TRIAL VERSION
-$VERSION = eval $VERSION;
+our $VERSION = '1.08'; # VERSION
 
 
 sub description { 'Start application with Morbo server' };
@@ -57,7 +56,7 @@ Clustericious::Command::morbo - Clustericious command to stat nginx
 
 =head1 VERSION
 
-version 1.28_01
+version 1.08
 
 =head1 DESCRIPTION
 
@@ -82,8 +81,6 @@ Contributors:
 
 Curt Tilmes
 
-Yanick Champoux
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by NASA GSFC.
