@@ -6,9 +6,11 @@ use Clustericious::Log;
 use Clustericious::App;
 use Mojo::Server::PSGI;
 use base 'Clustericious::Command';
+use File::Which qw( which );
+use Mojo::URL;
 
 # ABSTRACT: Clustericious command to start plack server
-our $VERSION = '1.07'; # VERSION
+our $VERSION = '1.08'; # VERSION
 
 
 __PACKAGE__->attr(description => <<EOT);
@@ -21,21 +23,30 @@ Starts a plack server.  See plackup for valid options.
 EOT
 
 sub run {
-    my $self = shift;
-    my @args = @_ ? @_ : @ARGV;
-    my $app_name = $ENV{MOJO_APP};
-    my $conf = Clustericious::Config->new( $app_name );
+  my($self, @args) = @_;
+  my $app_name = $ENV{MOJO_APP};
+  
+  Clustericious::App->init_logging;
 
-    Clustericious::App->init_logging;
+  my $plackup = which('plackup') || LOGDIE "could not find plackup in $ENV{PATH}";
 
-    my $plackup = qx[which plackup] or LOGDIE "could not find plackup in $ENV{PATH}";
-    chomp $plackup;
-
-    DEBUG "starting $plackup @args";
-    delete $ENV{MOJO_COMMANDS_DONE};
-    system( $plackup, @args ) == 0
-      or die "could not start $plackup @args ($?) "
-      . ( ${^CHILD_ERROR_NATIVE} || '' );
+  my $url = Mojo::URL->new($self->app->config->url);
+  LOGDIE "@{[ $url->scheme ]} not supported" if $url->scheme ne 'http';
+  
+  shift @args if $args[0] eq 'plackup';
+  push @args, $0;
+  unshift @args, '--port' => $url->port;
+  unshift @args, '--host' => $url->host;
+  
+  #if(my $pid_file = $self->app->config->plackup(default => {})->pid_file(default => 0))
+  #{
+  #  unshift @args, '--pidfile' => $pid_file;
+  #}
+  
+  DEBUG "starting $plackup @args";
+  delete $ENV{MOJO_COMMANDS_DONE};
+  print "PID = $$\n";
+  exec $plackup, @args;
 }
 
 1;
@@ -52,19 +63,17 @@ Clustericious::Command::plackup - Clustericious command to start plack server
 
 =head1 VERSION
 
-version 1.07
+version 1.08
 
 =head1 SYNOPSIS
 
- % yourapp start
+ % yourapp plackup
 
 =head1 DESCRIPTION
 
-Start a plack server using plackup.
-
-=head1 SUPER CLASS
-
-L<Clustericious::Command>
+Start a plack server using plackup.  By default plackup does not daemonize into the
+background, making it a handy development server.  Any arguments will be passed into
+the plackup command directly.
 
 =head1 SEE ALSO
 
