@@ -11,7 +11,6 @@ use Mojo::Template;
 use Log::Log4perl qw( :nowarn );
 use Storable ();
 use Clustericious::Config::Helpers ();
-use Cwd ();
 use File::HomeDir ();
 use Mojo::URL;
 use File::Spec;
@@ -19,7 +18,7 @@ use File::Temp ();
 use Carp ();
 
 # ABSTRACT: Configuration files for Clustericious nodes.
-our $VERSION = '1.07'; # VERSION
+our $VERSION = '1.08'; # VERSION
 
 
 our %singletons;
@@ -77,10 +76,17 @@ sub new {
       print $fh $$arg;
       close $fh;
     }
-    elsif($arg =~ /\.(conf|yml)$/)
+    elsif($arg =~ /\.conf$/)
     {
       $filename = $arg;
     }
+    elsif($arg =~ /\.yml$/)
+    {
+      # when we remove this alos remove the reference below
+      # when we mangle the name
+      Carp::carp("Config with .yml extension is deprecated");
+      $filename = $arg;
+    }
     else
     {
       my $name = $arg;
@@ -96,7 +102,7 @@ sub new {
         $conf_data = {};
       }
     }
-    
+
     if ($filename) {
       $logger->trace("reading from config file $filename") if $logger->is_trace;
       $callback->(pre_rendered => $filename);
@@ -112,6 +118,8 @@ sub new {
         ? eval { YAML::XS::Load($rendered) }
         : eval { JSON::MaybeXS::decode_json $rendered };
       $logger->logdie("Could not parse $type\n-------\n$rendered\n---------\n$@\n") if $@;
+    } else {
+      $callback->('not_found' => "$arg");
     }
   }
 
@@ -184,6 +192,7 @@ sub AUTOLOAD {
     elsif($default_exists)
     {
       $value = $self->{$called} = ref $default eq 'CODE' ? $default->() : $default;
+      $obj = ref $value eq 'HASH' ? $invocant->new($value) : undef;
     }
     else
     {
@@ -214,22 +223,6 @@ sub set_singleton {
   $singletons{$app} = $obj;
 }
 
-sub _default_start_mode {
-  my $self = shift;
-  $self->start_mode(default => sub {
-    $self->hypnotoad(default => sub {
-      my $url = Mojo::URL->new($self->url);
-      {
-        pid_file => File::Spec->catfile( File::HomeDir->my_dist_data("Clustericious", { create => 1 } ), 'hypnotoad-' . $url->port . '-' . $url->host . '.pid' ),
-        listen => [
-          $url->to_string,
-        ],
-      }
-    });
-    [ 'hypnotoad' ];
-  });
-}
-
 
 package Clustericious::Config::Callback;
 
@@ -276,7 +269,7 @@ Clustericious::Config - Configuration files for Clustericious nodes.
 
 =head1 VERSION
 
-version 1.07
+version 1.08
 
 =head1 SYNOPSIS
 
