@@ -3,72 +3,64 @@ package Clustericious::RouteBuilder::Common;
 use strict;
 use warnings;
 use 5.010;
-use Clustericious::Log;
-use Sys::Hostname qw/hostname/;
+use Sys::Hostname ();
 
 # ABSTRACT: Routes common to all clustericious applications
-our $VERSION = '1.07'; # VERSION
+our $VERSION = '1.08'; # VERSION
 
 
 sub _add_routes {
-    my $class = shift;
-    my $app = shift;
+  my $class = shift;
+  my $app = shift;
 
 
-    $app->routes->get('/version')->to(
-        cb => sub {
-            my $self = shift;
-            $self->stash(autodata => [ $self->app->VERSION // 'dev' ]);
-        }
-    );
+  $app->routes->get('/version')->to(cb => sub {
+    my $self = shift;
+    $self->stash(autodata => [ $self->app->VERSION // 'dev' ]);
+  });
 
 
-    $app->routes->get('/status')->to(
-        cb => sub {
-            my $self = shift;
-            my $app = ref $self->app || $self->app;
-            $self->stash(autodata => { app_name => $app,
-                                     server_version => $self->app->VERSION // 'dev',
-                                     server_hostname => hostname(),
-                                     server_url => $self->config->url(default => 'undef') });
-        }
-    );
+  $app->routes->get('/status')->to(cb => sub {
+    my($self) = @_;
+    my $app = ref $self->app || $self->app;
+
+    $self->stash(autodata => {
+      app_name => $app,
+      server_version => $self->app->VERSION // 'dev',
+      server_hostname => Sys::Hostname::hostname(),
+      server_url => $self->url_for('/')->to_abs->to_string,
+    });
+  });
 
 
-    $app->routes->get('/api')->to(
-        cb => sub {
-            my $self = shift;
-            $self->render( autodata => [ $self->app->dump_api() ] );
-            }
-    );
+  $app->routes->get('/api')->to(cb => sub {
+    my $self = shift;
+    $self->render( autodata => [ $self->app->dump_api() ] );
+  });
 
 
-    $app->routes->get('/api/:table')->to(
-        cb => sub {
-            my($self) = @_;
-            my $table = $self->app->dump_api_table($self->stash('table'));
-            $table ? $self->render( autodata => $table ) : $self->reply->not_found;
-        },
-    );
-    
+  $app->routes->get('/api/:table')->to(cb => sub {
+    my($self) = @_;
+    my $table = $self->app->dump_api_table($self->stash('table'));
+    $table ? $self->render( autodata => $table ) : $self->reply->not_found;
+  });
+  
 
-    $app->routes->get('/log/:lines' => [ lines => qr/\d+/ ] =>
-        sub {
-            my $c = shift;
-            my $lines = $c->stash("lines");
-            unless ($c->config->export_logs(default => 0)) {
-                return $c->render_text('logs not available');
-            }
-            $c->render_text(Clustericious::Log->tail(lines => $lines || 10) || '** empty log **');
-        });
+  $app->routes->get('/log/:lines' => [ lines => qr/\d+/ ] => sub {
+    my $c = shift;
+    my $lines = $c->stash("lines");
+    unless ($c->config->export_logs(default => 0)) {
+      return $c->render_text('logs not available');
+    }
+    $c->render_text(Clustericious::Log->tail(lines => $lines || 10) || '** empty log **');
+  });
 
-    $app->routes->options('/*opturl' => { opturl => '' } =>
-        sub {
-            my $c = shift;
-            $c->res->headers->add( 'Access-Control-Allow-Methods' => 'GET, POST, OPTIONS' );
-            # Allow-Origin and Allow-Headers added in after_dispatch hook.
-            $c->render_text('ok');
-        });
+  $app->routes->options('/*opturl' => { opturl => '' } => sub {
+    my $c = shift;
+    $c->res->headers->add( 'Access-Control-Allow-Methods' => 'GET, POST, OPTIONS' );
+    # Allow-Origin and Allow-Headers added in after_dispatch hook.
+    $c->render_text('ok');
+  });
 }
 
 1;
@@ -85,7 +77,7 @@ Clustericious::RouteBuilder::Common - Routes common to all clustericious applica
 
 =head1 VERSION
 
-version 1.07
+version 1.08
 
 =head1 DESCRIPTION
 
