@@ -3,11 +3,9 @@ package Clustericious::RouteBuilder::Search;
 use strict;
 use warnings;
 use Clustericious::Log;
-use List::MoreUtils qw/uniq/;
-use Data::Dumper;
 
 # ABSTRACT: build routes for searching for objects
-our $VERSION = '1.07'; # VERSION
+our $VERSION = '1.08'; # VERSION
 
 
 use Sub::Exporter -setup => {
@@ -51,7 +49,7 @@ sub _build_search {
         }
 
 
-        TRACE "searching for $items : ".Dumper($p);
+        #TRACE "searching for $items : ".Dumper($p);
 
         # maybe restrict, by first calling $manager->normalize_get_objects_args(%$p)
 
@@ -94,7 +92,7 @@ Clustericious::RouteBuilder::Search - build routes for searching for objects
 
 =head1 VERSION
 
-version 1.07
+version 1.08
 
 =head1 SYNOPSIS
 
