@@ -3,32 +3,30 @@ package Test::Clustericious::Command;
 use strict;
 use warnings;
 use 5.010001;
-use Test2::Plugin::FauxHomeDir;
-use File::Glob qw( bsd_glob );
-use base qw( Exporter );
+use if !$INC{'File/HomeDir/Test.pm'}, 'File::HomeDir::Test';
+use base qw( Exporter Test::Builder::Module );
 use Exporter qw( import );
 use Mojo::Loader;
 use Path::Class qw( file dir );
+use File::HomeDir;
 use Env qw( @PERL5LIB @PATH );
 use Capture::Tiny qw( capture );
 use File::Which qw( which );
 use File::Glob qw( bsd_glob );
 use YAML::XS ();
 use File::Temp qw( tempdir );
-use Test2::API qw( context );
 
 # ABSTRACT: Test Clustericious commands
-our $VERSION = '1.28_01'; # TRIAL VERSION
-$VERSION = eval $VERSION;
+our $VERSION = '1.08'; # VERSION
 
 
 our @EXPORT      = qw( extract_data mirror requires run_ok generate_port note_file clean_file create_symlink );
 our @EXPORT_OK   = @EXPORT;
 our %EXPORT_TAGS = ( all => \@EXPORT );
 
-unshift @INC, dir(bsd_glob '~/lib')->stringify;
+unshift @INC, dir(File::HomeDir->my_home, 'lib')->stringify;
 unshift @PERL5LIB, map { dir($_)->absolute->stringify } @INC;
-unshift @PATH, dir(bsd_glob '~/bin')->stringify;
+unshift @PATH, dir(File::HomeDir->my_home, 'bin')->stringify;
 
 sub _can_execute_in_tmp
 {
@@ -40,17 +38,17 @@ sub _can_execute_in_tmp
   $exit == 0;
 }
 
+
 sub requires
 {
   my($command, $num) = @_;
+  my $tb = __PACKAGE__->builder;
 
-  my $ctx = context();
-  $ctx->plan( 0, 'SKIP', 'test requires execute in tmp') unless __PACKAGE__->_can_execute_in_tmp;
+  $tb->plan( skip_all => 'test requires execute in tmp') unless __PACKAGE__->_can_execute_in_tmp;
 
   unless(defined $command)
   {
-    $ctx->plan( $num ) if defined $num;
-    $ctx->release;
+    $tb->plan( tests => $num ) if defined $num;
     return;
   }
 
@@ -65,51 +63,51 @@ sub requires
         my %config = %$config;
         \%config;
       }->{$name};
-      $ctx->plan( 0, 'SKIP', "developer test not configured" ) unless defined $config;
+      $tb->plan( skip_all => "developer test not configured" ) unless defined $config;
       
       unshift @PATH, $config->{path} if defined $config->{path};
-      unshift @PATH, dir(bsd_glob '~/bin')->stringify;
+      unshift @PATH, dir(File::HomeDir->my_home, 'bin')->stringify;
       $ENV{$_} = $config->{env}->{$_} for keys %{ $config->{env} };
       $command = $config->{exe} // $name;
     }
     else
     {
-      $ctx->plan( 0, 'SKIP', "developer only test" );
+      $tb->plan( skip_all => "developer only test" );
     }
   }
 
   if(which $command)
   {
-    $ctx->plan( $num ) if defined $num;
+    $tb->plan( tests => $num ) if defined $num;
   }
   else
   {
-    $ctx->plan( 0, 'SKIP', "test requires $command to be in the PATH" );
+    $tb->plan( skip_all => "test requires $command to be in the PATH" );
   }
-  $ctx->release;
 }
 
+
 sub extract_data
 {
   my(@values) = @_;
   my $caller = caller;
-  Mojo::Loader::load_class($caller) unless $caller eq 'main';
+  Mojo::Loader::load_class $caller;
   my $all = Mojo::Loader::data_section $caller;
   
-  my $ctx = context();
+  my $tb = __PACKAGE__->builder;
   
   foreach my $name (sort keys %$all)
   {
-    my $file = file(bsd_glob('~'), $name);
+    my $file = file(File::HomeDir->my_home, $name);
     my $dir  = $file->parent;
     unless(-d $dir)
     {
-      $ctx->note("[extract] DIR  $dir");
+      $tb->note("[extract] DIR  $dir");
       $dir->mkpath(0,0700);
     }
     unless(-f $file)
     {
-      $ctx->note("[extract] FILE $file@{[ $name =~ m{^bin/} ? ' (*)' : '']}");
+      $tb->note("[extract] FILE $file@{[ $name =~ m{^bin/} ? ' (*)' : '']}");
       
       if($name =~ m{^bin/})
       {
@@ -124,21 +122,20 @@ sub extract_data
       }
     }
   }
-  
-  $ctx->release;
 }
 
+
 sub mirror
 {
   my($src, $dst) = map { ref($_) ? $_ : dir($_) } @_;
   
-  my $ctx = context();
+  my $tb = __PACKAGE__->builder;
 
-  $dst = dir(bsd_glob('~'), $dst) unless $dst->is_absolute;
+  $dst = dir(File::HomeDir->my_home, $dst) unless $dst->is_absolute;
   
   unless(-d $dst)
   {
-    $ctx->note("[mirror ] DIR  $dst");
+    $tb->note("[mirror ] DIR  $dst");
     $dst->mkpath(0,0700);
   }
   
@@ -155,7 +152,7 @@ sub mirror
       {
         if(-x $child)
         {
-          $ctx->note("[mirror ] FILE $dst (*)");
+          $tb->note("[mirror ] FILE $dst (*)");
           my $content = scalar $child->slurp;
           $content =~ s{^#!/usr/bin/perl}{#!$^X};
           $dst->spew($content);
@@ -163,64 +160,55 @@ sub mirror
         }
         else
         {
-          $ctx->note("[mirror ] FILE $dst");
+          $tb->note("[mirror ] FILE $dst");
           $dst->spew(scalar $child->slurp);
           chmod 0600, "$dst";
         }
       }
     }
   }
-  
-  $ctx->release;
 }
 
+
 sub run_ok
 {
   my(@cmd) = @_;
-  
-  # Yath set some environment variables which confuse a subprocess
-  # for when we are testing the use of prove, etc
-  local %ENV = %ENV;
-  delete $ENV{$_} for grep /^T2_/, keys %ENV;
-  
   my($out, $err, $error, $exit) = capture { system @cmd; ($!,$?) };
   
   my $ok = ($exit != -1) && ! ($exit & 128);
   
-  my $ctx = context();
+  my $tb = __PACKAGE__->builder;
   
-  $ctx->ok($ok, "run: @cmd");
-  $ctx->diag("  @cmd failed") unless $ok;
-  $ctx->diag("    - execute failed: $error") if $exit == -1;
-  $ctx->diag("    - died from signal: " . ($exit & 128)) if $exit & 128;
+  $tb->ok($ok, "@cmd");
+  $tb->diag("  @cmd failed") unless $ok;
+  $tb->diag("    - execute failed: $error") if $exit == -1;
+  $tb->diag("    - died from signal: " . ($exit & 128)) if $exit & 128;
 
-  my $run = Test::Clustericious::Command::Run->new(
-    cmd => \@cmd,
+  Test::Clustericious::Command::Run->new(  
     out => $out, err => $err, exit => $exit >> 8,
   );
-  
-  $ctx->release;
-  
-  $run;
 }
 
+
 sub generate_port
 {
   require IO::Socket::INET;
   IO::Socket::INET->new(Listen => 5, LocalAddr => "127.0.0.1")->sockport;
 }
 
+
 sub note_file
 {
-  my $ctx = context();
+  my $tb = __PACKAGE__->builder;
+
   foreach my $file (sort map { file $_ } map { bsd_glob "~/$_" } @_)
   {
-    $ctx->note("[content] $file");
-    $ctx->note(scalar $file->slurp);
+    $tb->note("[content] $file");
+    $tb->note(scalar $file->slurp);
   }
-  $ctx->release;
 }
 
+
 sub clean_file
 {
   foreach my $file (sort map { file $_ } map { bsd_glob "~/$_" } @_)
@@ -229,13 +217,13 @@ sub clean_file
   }
 }
 
+
 sub create_symlink
 {
-  my($old,$new) = map { file(bsd_glob('~'), $_) } @_;
+  my $tb = __PACKAGE__->builder;
+  my($old,$new) = map { file(File::HomeDir->my_home, $_) } @_;
   $new->remove if -f $new;
-  my $ctx = context();
-  $ctx->note("[symlink] $old => $new");
-  $ctx->release;
+  $tb->note("[symlink] $old => $new");
   use autodie;
   symlink "$old", "$new";
   %Clustericious::Config::singletons = ();
@@ -243,7 +231,7 @@ sub create_symlink
 
 package Test::Clustericious::Command::Run;
 
-use Test2::API qw( context );
+use base qw( Test::Builder::Module );
 
 sub new
 {
@@ -251,7 +239,6 @@ sub new
   bless \%args, $class;
 }
 
-sub cmd { @{ shift->{cmd} // [] } }
 sub out { shift->{out} }
 sub err { shift->{err} }
 sub exit { shift->{exit} }
@@ -260,46 +247,36 @@ sub exit_is
 {
   my($self, $value, $name) = @_;
   $name //= "exit with $value";
-  my $ctx = context();
-  $ctx->ok($self->exit eq $value, $name);
-  unless($self->exit == $value)
-  {
-    $ctx->diag("[cmd]\n", join(' ', $self->cmd)) if $self->cmd;
-    $ctx->diag("[out]\n", $self->out) if $self->out;
-    $ctx->diag("[err]\n", $self->err) if $self->err;
-  }
-  $ctx->release;
+  my $tb = __PACKAGE__->builder;
+  $tb->is_eq($self->exit, $value, $name);
   $self;
 }
 
 sub note
 {
   my($self) = @_;
-  my $ctx = context();
-  $ctx->note("[out]\n" . $self->out) if $self->out;
-  $ctx->note("[err]\n" . $self->err) if $self->err;
-  $ctx->release;
+  my $tb = __PACKAGE__->builder;
+  $tb->note("[out]\n" . $self->out) if $self->out;
+  $tb->note("[err]\n" . $self->err) if $self->err;
   $self;
 }
 
 sub diag
 {
   my($self) = @_;
-  my $ctx = context();
-  $ctx->diag("[out]\n" . $self->out) if $self->out;
-  $ctx->diag("[err]\n" . $self->err) if $self->err;
-  $ctx->release;
+  my $tb = __PACKAGE__->builder;
+  $tb->diag("[out]\n" . $self->out) if $self->out;
+  $tb->diag("[err]\n" . $self->err) if $self->err;
   $self;
 }
 
 sub out_like
 {
   my($self, $pattern, $name) = @_;
-
-  my $ctx = context();
+  my $tb = __PACKAGE__->builder;
+  
   $name ||= "output matches";
-  $ctx->ok($self->out =~ $pattern, $name);
-  $ctx->release;
+  $tb->like($self->out, $pattern, $name);
 
   $self;
 }
@@ -307,11 +284,10 @@ sub out_like
 sub out_unlike
 {
   my($self, $pattern, $name) = @_;
-
-  my $ctx = context();  
+  my $tb = __PACKAGE__->builder;
+  
   $name ||= "output does not match";
-  $ctx->ok($self->out !~ $pattern, $name);
-  $ctx->release;
+  $tb->unlike($self->out, $pattern, $name);
 
   $self;
 }
@@ -319,11 +295,10 @@ sub out_unlike
 sub err_like
 {
   my($self, $pattern, $name) = @_;
-
-  my $ctx = context();  
+  my $tb = __PACKAGE__->builder;
+  
   $name ||= "error matches";
-  $ctx->ok($self->err =~ $pattern, $name);
-  $ctx->release;
+  $tb->like($self->err, $pattern, $name);
 
   $self;
 }
@@ -331,11 +306,10 @@ sub err_like
 sub err_unlike
 {
   my($self, $pattern, $name) = @_;
-
-  my $ctx = context();
+  my $tb = __PACKAGE__->builder;
+  
   $name ||= "error does not match";
-  $ctx->unlike($self->err, $pattern, $name);
-  $ctx->release;
+  $tb->unlike($self->err, $pattern, $name);
   
   $self;
 }
@@ -361,7 +335,7 @@ Test::Clustericious::Command - Test Clustericious commands
 
 =head1 VERSION
 
-version 1.28_01
+version 1.08
 
 =head1 SYNOPSIS
 
@@ -369,8 +343,25 @@ version 1.28_01
 
 =head1 DESCRIPTION
 
-This is currently a private module used internally by L<Clustericious>.  This may change in the future,
-but for now you should not depend on it providing any functionality.
+Documentation to be added later.
+
+=head1 FUNCTIONS
+
+=head2 requires
+
+=head2 extract_data
+
+=head2 mirror
+
+=head2 run_ok
+
+=head2 generate_port
+
+=head2 note_file
+
+=head2 clean_file
+
+=head2 create_symlink
 
 =head1 AUTHOR
 
@@ -382,8 +373,6 @@ Contributors:
 
 Curt Tilmes
 
-Yanick Champoux
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by NASA GSFC.
