@@ -3,15 +3,7 @@ package Test::Clustericious::Config;
 use strict;
 use warnings;
 use 5.010001;
-
-BEGIN {
-  unless($INC{'File/HomeDir/Test.pm'})
-  {
-    eval q{ use File::HomeDir::Test };
-    die $@ if $@;
-  }
-}
-
+use if !$INC{'File/HomeDir/Test.pm'}, 'File::HomeDir::Test';
 use File::HomeDir;
 use YAML::XS qw( DumpFile );
 use File::Path qw( mkpath );
@@ -38,7 +30,7 @@ sub _init
 BEGIN { _init() }
 
 # ABSTRACT: Test Clustericious::Config
-our $VERSION = '1.07'; # VERSION
+our $VERSION = '1.08'; # VERSION
 
 
 sub create_config_ok ($;$$)
@@ -157,7 +149,7 @@ Test::Clustericious::Config - Test Clustericious::Config
 
 =head1 VERSION
 
-version 1.07
+version 1.08
 
 =head1 SYNOPSIS
 
